16.98. cdist-type__mysql_user(7) — cdist 6.9.8 documentation

# 16.98. cdist-type__mysql_user(7)

## 16.98.1. NAME

cdist-type__mysql_user - Manage a MySQL user

## 16.98.2. DESCRIPTION

Create MySQL user or change password for the user.

## 16.98.3. OPTIONAL PARAMETERS

name

  Name of user. Defaults to object id.

host

  Host of user. Defaults to localhost.

password

  Password of user.

state

  Defaults to present.

## 16.98.4. EXAMPLES

    __mysql_user user --password secret

## 16.98.5. AUTHORS

Ander Punnar <ander-at-kvlt-dot-ee>

## 16.98.6. COPYING

Copyright (C) 2020 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.